@@ -376,8 +376,8 @@ MetadataTableNames = {
     0x1b: "TypeSpec",
     0x1c: "ImplMap",
     0x1d: "FieldRVA",
-    0x1e: None,
-    0x1f: None,
+    0x1e: "EncLog",
+    0x1f: "EncRow",
     0x20: "Assembly",
     0x21: "AssemblyProcessor",
     0x22: "AssemblyOS",
@@ -552,8 +552,8 @@ def MetadataTableDefinitions(dt, netMetaDataStreams):
             { "rva": datatypes.DWORD() },
             { "field": FieldIndex(dt, netMetaDataStreams) },
         ],
-        0x1e: None,
-        0x1f: None,
+        0x1E: [{"token": datatypes.DWORD(), "funcCode": datatypes.BYTE()}],
+        0x1F: [{"token": datatypes.DWORD()}],
         0x20: [
             { "hashAlgId": datatypes.DWORD() },
             { "majorVersion": datatypes.WORD() },
